<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>Object</name>
    <message>
        <source>Duplicate scoped enum name</source>
        <translation>잘못된 범위 한정 열거형 이름</translation>
    </message>
    <message>
        <source>Duplicate signal name</source>
        <translation>중복된 시그널 이름</translation>
    </message>
    <message>
        <source>Duplicate property name</source>
        <translation>중복된 속성 이름</translation>
    </message>
    <message>
        <source>Property names cannot begin with an upper case letter</source>
        <translation>속성 이름은 대문자로 시작할 수 없음</translation>
    </message>
    <message>
        <source>Duplicate default property</source>
        <translation>중복된 기본 속성</translation>
    </message>
    <message>
        <source>Duplicate alias name</source>
        <translation>중복된 별명 이름</translation>
    </message>
    <message>
        <source>Alias names cannot begin with an upper case letter</source>
        <translation>별명 이름은 대문자로 시작할 수 없음</translation>
    </message>
    <message>
        <source>Property value set multiple times</source>
        <translation>속성 값이 여러 번 설정됨</translation>
    </message>
</context>
<context>
    <name>QQmlAnonymousComponentResolver</name>
    <message>
        <source>Component objects cannot declare new functions.</source>
        <translation>컴포넌트 객체에서는 새로운 함수를 정의할 수 없습니다.</translation>
    </message>
    <message>
        <source>Component objects cannot declare new properties.</source>
        <translation>컴포넌트 객체에서는 새로운 속성을 정의할 수 없습니다.</translation>
    </message>
    <message>
        <source>Component objects cannot declare new signals.</source>
        <translation>컴포넌트 객체에서는 새로운 시그널을 정의할 수 없습니다.</translation>
    </message>
    <message>
        <source>Cannot create empty component specification</source>
        <translation>비어 있는 컴포넌트 정의를 만들 수 없음</translation>
    </message>
    <message>
        <source>Component elements may not contain properties other than id</source>
        <translation>컴포넌트 원소는 id 이외의 다른 속성을 포함할 수 없음</translation>
    </message>
    <message>
        <source>Invalid component body specification</source>
        <translation>잘못된 컴포넌트 body 지정</translation>
    </message>
    <message>
        <source>id is not unique</source>
        <translation>중복되는 id가 있음</translation>
    </message>
    <message>
        <source>Circular alias reference detected</source>
        <translation>순환 별명 참조 감지됨</translation>
    </message>
    <message>
        <source>Invalid alias reference. Unable to find id &quot;%1&quot;</source>
        <translation>잘못된 별명 참조. id &quot;%1&quot;을(를) 찾을 수 없음</translation>
    </message>
    <message>
        <source>Invalid alias target location: %1</source>
        <translation>잘못된 별명 대상 위치: %1</translation>
    </message>
</context>
<context>
    <name>QQmlCodeGenerator</name>
    <message>
        <source>Property value set multiple times</source>
        <translation>속성 값이 여러 번 설정됨</translation>
    </message>
    <message>
        <source>Expected type name</source>
        <translation>형식 이름이 필요함</translation>
    </message>
    <message>
        <source>Signal names cannot begin with an upper case letter</source>
        <translation>시그널 이름은 대문자로 시작할 수 없음</translation>
    </message>
    <message>
        <source>Illegal signal name</source>
        <translation>잘못된 시그널 이름</translation>
    </message>
    <message>
        <source>No property alias location</source>
        <translation>속성 별명 위치가 지정되지 않음</translation>
    </message>
    <message>
        <source>Invalid alias reference. An alias reference must be specified as &lt;id&gt;, &lt;id&gt;.&lt;property&gt; or &lt;id&gt;.&lt;value property&gt;.&lt;property&gt;</source>
        <translation>잘못된 별명 참조. 별명 참조는 &lt;id&gt;, &lt;id&gt;.&lt;property&gt; 또는 &lt;id&gt;.&lt;value property&gt;.&lt;property&gt;여야 함</translation>
    </message>
    <message>
        <source>Invalid alias location</source>
        <translation>잘못된 별명 위치</translation>
    </message>
    <message>
        <source>Illegal property name</source>
        <translation>잘못된 속성 이름</translation>
    </message>
    <message>
        <source>Duplicate method name</source>
        <translation>중복된 메서드 이름</translation>
    </message>
    <message>
        <source>Method names cannot begin with an upper case letter</source>
        <translation>메서드 이름은 대문자로 시작할 수 없음</translation>
    </message>
    <message>
        <source>Illegal method name</source>
        <translation>잘못된 메서드 이름</translation>
    </message>
    <message>
        <source>Scoped enum names must begin with an upper case letter</source>
        <translation>범위 한정 열거형 이름은 대문자로 시작해야 함</translation>
    </message>
    <message>
        <source>Enum names must begin with an upper case letter</source>
        <translation>열거형 이름은 대문자로 시작해야 함</translation>
    </message>
    <message>
        <source>Enum value must be an integer</source>
        <translation>열거형 값은 정수여야 함</translation>
    </message>
    <message>
        <source>Enum value out of range</source>
        <translation>열거형 값이 범위를 벗어남</translation>
    </message>
    <message>
        <source>Invalid component id specification</source>
        <translation>잘못된 컴포넌트 id 지정</translation>
    </message>
    <message>
        <source>Invalid empty ID</source>
        <translation>잘못된 빈 ID</translation>
    </message>
    <message>
        <source>IDs cannot start with an uppercase letter</source>
        <translation>ID는 대문자로 시작할 수 없음</translation>
    </message>
    <message>
        <source>IDs must start with a letter or underscore</source>
        <translation>ID는 글자나 밑줄로 시작해야 함</translation>
    </message>
    <message>
        <source>IDs must contain only letters, numbers, and underscores</source>
        <translation>ID는 글자, 숫자, 밑줄만 포함해야 함</translation>
    </message>
    <message>
        <source>ID illegally masks global JavaScript property</source>
        <translation>ID가 전역 자바스크립트 속성을 가림</translation>
    </message>
    <message>
        <source>Invalid use of id property</source>
        <translation>id 속성을 잘못 사용함</translation>
    </message>
</context>
<context>
    <name>QQmlComponent</name>
    <message>
        <source>Invalid empty URL</source>
        <translation>잘못된 빈 URL</translation>
    </message>
    <message>
        <source>createObject: value is not an object</source>
        <translation>createObject: 값이 객체가 아님</translation>
    </message>
    <message>
        <source>Object or context destroyed during incubation</source>
        <translation>객체나 콘텍스트를 만드는 중 파괴됨</translation>
    </message>
</context>
<context>
    <name>QQmlConnections</name>
    <message>
        <source>Cannot assign to non-existent property &quot;%1&quot;</source>
        <translation>존재하지 않는 속성 &quot;%1&quot;에 할당할 수 없음</translation>
    </message>
    <message>
        <source>Connections: nested objects not allowed</source>
        <translation>연결: 중첩된 객체를 사용할 수 없음</translation>
    </message>
    <message>
        <source>Connections: syntax error</source>
        <translation>연결: 문법 오류</translation>
    </message>
    <message>
        <source>Connections: script expected</source>
        <translation>연결: 스크립트가 필요함</translation>
    </message>
    <message>
        <source>Implicitly defined onFoo properties in Connections are deprecated. Use this syntax instead: function onFoo(&lt;arguments&gt;) { ... }</source>
        <translation>Connections 객체에 암시적으로 선언된 onFoo 속성은 오래되었습니다. 다음 문법을 대신 사용하십시오: function onFoo(&lt;arguments&gt;) { ... }</translation>
    </message>
    <message>
        <source>Detected function &quot;%1&quot; in Connections element. This is probably intended to be a signal handler but no signal of the target matches the name.</source>
        <translation>Connections 원소에서 &quot;%1&quot; 함수를 감지했습니다. 시그널 처리기인 것 같지만 대상의 시그널 중에 그러한 이름을 가진 것이 없습니다.</translation>
    </message>
</context>
<context>
    <name>QQmlDebugServerImpl</name>
    <message>
        <source>QML Debugger: Invalid argument &quot;%1&quot; detected. Ignoring the same.</source>
        <translation>QML 디버거: 잘못된 인자 &quot;%1&quot;이(가) 감지되었습니다. 해당 인자를 무시합니다.</translation>
    </message>
    <message>
        <source>QML Debugger: Ignoring &quot;-qmljsdebugger=%1&quot;.</source>
        <translation>QML 디버거: &quot;-qmljsdebugger=%1&quot; 인자를 무시합니다.</translation>
    </message>
    <message>
        <source>The format is &quot;-qmljsdebugger=[file:&lt;file&gt;|port:&lt;port_from&gt;][,&lt;port_to&gt;][,host:&lt;ip address&gt;][,block][,services:&lt;service&gt;][,&lt;service&gt;]*&quot;</source>
        <translation>올바른 형식은 &quot;-qmljsdebugger=[file:&lt;file&gt;|port:&lt;port_from&gt;][,&lt;port_to&gt;][,host:&lt;ip address&gt;][,block][,services:&lt;service&gt;][,&lt;service&gt;]*&quot;입니다</translation>
    </message>
    <message>
        <source>&quot;file:&quot; can be used to specify the name of a file the debugger will try to connect to using a QLocalSocket. If &quot;file:&quot; is given any &quot;host:&quot; and&quot;port:&quot; arguments will be ignored.</source>
        <translation>&quot;file:&quot; 인자는 디버거에서 QLocalSocket을 통해 연결할 파일입니다. &quot;file:&quot; 인자를 지정하면 &quot;host:&quot; 및 &quot;port:&quot; 인자를 무시합니다.</translation>
    </message>
    <message>
        <source>&quot;host:&quot; and &quot;port:&quot; can be used to specify an address and a single port or a range of ports the debugger will try to bind to with a QTcpServer.</source>
        <translation>&quot;host:&quot; 및 &quot;port:&quot; 인자는 디버거에서 QTcpServer를 통해 연결할 호스트 주소나 단일 포트 및 포트 범위입니다.</translation>
    </message>
    <message>
        <source>&quot;block&quot; makes the debugger and some services wait for clients to be connected and ready before the first QML engine starts.</source>
        <translation>&quot;block&quot; 인자를 지정하면 디버거와 일부 서비스가 첫 QML 엔진을 시작할 때까지 클라이언트가 연결되고 준비되기를 기다립니다.</translation>
    </message>
    <message>
        <source>&quot;services:&quot; can be used to specify which debug services the debugger should load. Some debug services interact badly with others. The V4 debugger should not be loaded when using the QML profiler as it will force any V4 engines to use the JavaScript interpreter rather than the JIT. The following debug services are available by default:</source>
        <translation>&quot;services:&quot; 인자는 디버거에서 불러올 디버그 서비스입니다. 일부 디버그 서비스는 서로간에 간섭을 발생시킬 수 있습니다. QML 프로파일러를 사용하면 V4 엔진이 JIT 대신 자바스크립트 인터프리터를 사용하는 것을 강제하므로, QML 프로파일러를 사용할 때에는 V4 디버거를 불러오지 말아야 합니다. 다음 디버그 서비스를 사용할 수 있습니다:</translation>
    </message>
    <message>
        <source>The QML debugger</source>
        <translation>QML 디버거</translation>
    </message>
    <message>
        <source>The V4 debugger</source>
        <translation>V4 디버거</translation>
    </message>
    <message>
        <source>The QML inspector</source>
        <translation>QML 검사 도구</translation>
    </message>
    <message>
        <source>The QML profiler</source>
        <translation>QML 프로파일러</translation>
    </message>
    <message>
        <source>Allows the client to delay the starting and stopping of
		  QML engines until other services are ready. QtCreator
		  uses this service with the QML profiler in order to
		  profile multiple QML engines at the same time.</source>
        <translation>다른 서비스가 준비될 때까지 클라이언트에서 QML 엔진 시작과 정지를
		  지연시킬 수 있도록 합니다. Qt Creator는 여러 개의
		  QML 엔진을 동시에 프로파일링할 수 있도록 이 서비스를
		  QML 프로파일러와 함께 사용합니다.</translation>
    </message>
    <message>
        <source>Sends qDebug() and similar messages over the QML debug
		  connection. QtCreator uses this for showing debug
		  messages in the debugger console.</source>
        <translation>QML 디버그 연결로 qDebug() 및 비슷한 메시지를 전송합니다.
		  Qt Creator는 디버거 콘솔에 디버그 메시지를
		  표시할 수 있도록 이 서비스를 사용합니다.</translation>
    </message>
    <message>
        <source>helps to see if a translated text
		  will result in an elided text
		  in QML elements.</source>
        <translation>번역된 문자열이 QML 원소에서
		  생략되어서 표시될지를
		  미리 볼 수 있습니다.</translation>
    </message>
    <message>
        <source>Other services offered by qmltooling plugins that implement QQmlDebugServiceFactory and which can be found in the standard plugin paths will also be available and can be specified. If no &quot;services&quot; argument is given, all services found this way, including the default ones, are loaded.</source>
        <translation>표준 플러그인 경로에서 찾을 수 있는 QQmlDebugServiceFactory를 구현하는 qmltooling 플러그인도 사용할 수 있으며 여기에 지정할 수 있습니다. &quot;services&quot; 인자를 지정하지 않으면 기본 서비스를 포함하여 여기에 해당하는 모든 서비스를 불러옵니다.</translation>
    </message>
</context>
<context>
    <name>QQmlDelegateModel</name>
    <message>
        <source>The delegate of a DelegateModel cannot be changed within onUpdated.</source>
        <translation>onUpdated 내에서 DelegateModel의 대리자를 변경할 수 없습니다.</translation>
    </message>
    <message>
        <source>The maximum number of supported DelegateModelGroups is 8</source>
        <translation>최대 8개까지 DelegateModelGroups를 지원합니다</translation>
    </message>
    <message>
        <source>The group of a DelegateModel cannot be changed within onChanged</source>
        <translation>onChanged 내에서 DelegateModel의 그룹을 변경할 수 없습니다</translation>
    </message>
    <message>
        <source>The delegates of a DelegateModel cannot be changed within onUpdated.</source>
        <translation>onUpdated 내에서 DelegateModel의 대리자를 변경할 수 없습니다.</translation>
    </message>
</context>
<context>
    <name>QQmlDelegateModelGroup</name>
    <message>
        <source>Group names must start with a lower case letter</source>
        <translation>그룹 이름은 소문자로 시작해야 함</translation>
    </message>
    <message>
        <source>get: index out of range</source>
        <translation>get: 인덱스가 범위를 벗어남</translation>
    </message>
    <message>
        <source>insert: index out of range</source>
        <translation>insert: 인덱스가 범위를 벗어남</translation>
    </message>
    <message>
        <source>create: index out of range</source>
        <translation>create: 인덱스가 범위를 벗어남</translation>
    </message>
    <message>
        <source>resolve: from index out of range</source>
        <translation>resolve: from 인덱스가 범위를 벗어남</translation>
    </message>
    <message>
        <source>resolve: from index invalid</source>
        <translation>resolve: from 인덱스가 잘못됨</translation>
    </message>
    <message>
        <source>resolve: to index out of range</source>
        <translation>resolve: to 인덱스가 범위를 벗어남</translation>
    </message>
    <message>
        <source>resolve: to index invalid</source>
        <translation>resolve: to 인덱스가 잘못됨</translation>
    </message>
    <message>
        <source>resolve: from is not an unresolved item</source>
        <translation>resolve: from이 해결되지 않은 항목이 아님</translation>
    </message>
    <message>
        <source>resolve: to is not a model item</source>
        <translation>resolve: to가 모델 항목이 아님</translation>
    </message>
    <message>
        <source>remove: invalid index</source>
        <translation>remove: 잘못된 인덱스</translation>
    </message>
    <message>
        <source>remove: index out of range</source>
        <translation>remove: 인덱스가 범위를 벗어남</translation>
    </message>
    <message>
        <source>remove: invalid count</source>
        <translation>remove: 개수가 잘못됨</translation>
    </message>
    <message>
        <source>addGroups: index out of range</source>
        <translation>addGroups: 인덱스가 범위를 벗어남</translation>
    </message>
    <message>
        <source>addGroups: invalid count</source>
        <translation>addGroups: 잘못된 개수</translation>
    </message>
    <message>
        <source>removeGroups: index out of range</source>
        <translation>removeGroups: 인덱스가 범위를 벗어남</translation>
    </message>
    <message>
        <source>removeGroups: invalid count</source>
        <translation>removeGroups: 잘못된 개수</translation>
    </message>
    <message>
        <source>setGroups: index out of range</source>
        <translation>setGroups: 인덱스가 범위를 벗어남</translation>
    </message>
    <message>
        <source>setGroups: invalid count</source>
        <translation>setGroups: 잘못된 개수</translation>
    </message>
    <message>
        <source>move: invalid from index</source>
        <translation>move: 잘못된 from 인덱스</translation>
    </message>
    <message>
        <source>move: invalid to index</source>
        <translation>move: 잘못된 to 인덱스</translation>
    </message>
    <message>
        <source>move: invalid count</source>
        <translation>move: 잘못된 개수</translation>
    </message>
    <message>
        <source>move: from index out of range</source>
        <translation>move: from 인덱스가 범위를 벗어남</translation>
    </message>
    <message>
        <source>move: to index out of range</source>
        <translation>move: to 인덱스가 범위를 벗어남</translation>
    </message>
</context>
<context>
    <name>QQmlEngine</name>
    <message>
        <source>Locale cannot be instantiated. Use Qt.locale()</source>
        <translation>로캘의 인스턴스를 생성할 수 없습니다.  Qt.locale()을 사용하십시오</translation>
    </message>
    <message>
        <source>There are still &quot;%1&quot; items in the process of being created at engine destruction.</source>
        <translation>엔진 삭제 중 생성되고 있는 &quot;%1&quot; 항목이 있습니다.</translation>
    </message>
    <message>
        <source>executeSql called outside transaction()</source>
        <translation>transaction() 밖에서 executeSql이 호출됨</translation>
    </message>
    <message>
        <source>Read-only Transaction</source>
        <translation>읽기 전용 트랜잭션</translation>
    </message>
    <message>
        <source>Version mismatch: expected %1, found %2</source>
        <translation>버전 불일치: 사용 중인 버전 %2, 필요한 버전 %1</translation>
    </message>
    <message>
        <source>SQL transaction failed</source>
        <translation>SQL 트랜잭션 실패</translation>
    </message>
    <message>
        <source>transaction: missing callback</source>
        <translation>트랜잭션: 콜백이 없음</translation>
    </message>
    <message>
        <source>SQL: can&apos;t create database, offline storage is disabled.</source>
        <translation>SQL: 데이터베이스를 만들 수 없음, 오프라인 저장소가 비활성화되었습니다.</translation>
    </message>
    <message>
        <source>LocalStorage: can&apos;t create path %1</source>
        <translation>LocalStorage: 경로 %1을(를) 만들 수 없음</translation>
    </message>
    <message>
        <source>SQL: database version mismatch</source>
        <translation>SQL: 데이터베이스 버전 불일치</translation>
    </message>
</context>
<context>
    <name>QQmlEnumTypeResolver</name>
    <message>
        <source>Invalid property assignment: Enum value &quot;%1&quot; cannot start with a lowercase letter</source>
        <translation>잘못된 속성 대입: 열거형 값 &quot;%1&quot;은(는) 소문자로 시작할 수 없음</translation>
    </message>
    <message>
        <source>Invalid property assignment: &quot;%1&quot; is a read-only property</source>
        <translation>잘못된 속성 대입: &quot;%1&quot;은(는) 읽기 전용 속성</translation>
    </message>
</context>
<context>
    <name>QQmlImportDatabase</name>
    <message>
        <source>&quot;%1&quot; is ambiguous. Found in %2 and in %3</source>
        <translation>&quot;%1&quot;이(가) 모호합니다. %2, %3에서 찾았습니다</translation>
    </message>
    <message>
        <source>- %1 is neither a type nor a namespace</source>
        <translation>- %1이(가) 형식이나 네임스페이스가 아님</translation>
    </message>
    <message>
        <source>- %1 is not a namespace</source>
        <translation>- %1이(가) 네임스페이스가 아님</translation>
    </message>
    <message>
        <source>- %1 is not a type</source>
        <translation>- %1이(가) 형식이 아님</translation>
    </message>
    <message>
        <source>- nested namespaces not allowed</source>
        <translation>- 중첩된 네임스페이스를 사용할 수 없음</translation>
    </message>
    <message>
        <source>local directory</source>
        <translation>로컬 디렉터리</translation>
    </message>
    <message>
        <source>is ambiguous. Found in %1 and in %2</source>
        <translation>이(가) 모호합니다. %1와(과) %2에서 찾았음</translation>
    </message>
    <message>
        <source>is ambiguous. Found in %1 in version %2.%3 and %4.%5</source>
        <translation>이(가) 모호합니다. %1에서 버전 %2.%3, %4.%5을(를) 찾았음</translation>
    </message>
    <message>
        <source>is instantiated recursively</source>
        <translation>이(가) 재귀적으로 인스턴스화됨</translation>
    </message>
    <message>
        <source>is not a type</source>
        <translation>이(가) 형식이 아님</translation>
    </message>
    <message>
        <source>static plugin for module &quot;%1&quot; with name &quot;%2&quot; has no metadata URI</source>
        <translation>이름이 &quot;%2&quot;인 모듈 &quot;%1&quot;의 정적 플러그인에 메타데이터 URI가 없음</translation>
    </message>
    <message>
        <source>module does not support the designer &quot;%1&quot;</source>
        <translation>모듈에서 디자이너 &quot;%1&quot;을(를) 지원하지 않음</translation>
    </message>
    <message>
        <source>plugin cannot be loaded for module &quot;%1&quot;: %2</source>
        <translation>모듈 &quot;%1&quot;의 플러그인을 불러올 수 없음: %2</translation>
    </message>
    <message>
        <source>static plugin for module &quot;%1&quot; with name &quot;%2&quot; cannot be loaded: %3</source>
        <translation>이름이 &quot;%2&quot;인 모듈 &quot;%1&quot;의 정적 플러그인을 불러올 수 없음: %3</translation>
    </message>
    <message>
        <source>could not resolve all plugins for module &quot;%1&quot;</source>
        <translation>모듈 &quot;%1&quot;의 모든 플러그인을 처리할 수 없음</translation>
    </message>
    <message>
        <source>module &quot;%1&quot; plugin &quot;%2&quot; not found</source>
        <translation>모듈 &quot;%1&quot;의 플러그인 &quot;%2&quot;을(를) 찾을 수 없음</translation>
    </message>
    <message>
        <source>&quot;%1&quot; version %2.%3 is defined more than once in module &quot;%4&quot;</source>
        <translation>&quot;%1&quot; 버전 %2.%3이(가) 모듈 &quot;%4&quot;에 한 번 이상 정의되었음</translation>
    </message>
    <message>
        <source>module &quot;%1&quot; version %2.%3 is not installed</source>
        <translation>모듈 &quot;%1&quot;의 버전 %2.%3이(가) 설치되지 않았음</translation>
    </message>
    <message>
        <source>module &quot;%1&quot; is not installed</source>
        <translation>모듈 &quot;%1&quot;이(가) 설치되지 않았음</translation>
    </message>
    <message>
        <source>&quot;%1&quot;: no such directory</source>
        <translation>&quot;%1&quot;: 그러한 디렉터리가 없음</translation>
    </message>
    <message>
        <source>import &quot;%1&quot; has no qmldir and no namespace</source>
        <translation>import &quot;%1&quot;에 qmldir과 네임스페이스가 없음</translation>
    </message>
    <message>
        <source>File name case mismatch for &quot;%1&quot;</source>
        <translation>파일 이름의 대소문자가 &quot;%1&quot;와(과) 일치하지 않음</translation>
    </message>
</context>
<context>
    <name>QQmlListModel</name>
    <message>
        <source>unable to enable dynamic roles as this model is not empty</source>
        <translation>모델이 비어 있지 않아서 동적 역할을 사용할 수 없음</translation>
    </message>
    <message>
        <source>unable to enable static roles as this model is not empty</source>
        <translation>모델이 비어 있지 않아서 정적 역할을 사용할 수 없음</translation>
    </message>
    <message>
        <source>dynamic role setting must be made from the main thread, before any worker scripts are created</source>
        <translation>동적 역할 설정은 작업자 스크립트가 생성되기 전 주 스레드에서 정의되어야 함</translation>
    </message>
    <message>
        <source>remove: indices [%1 - %2] out of range [0 - %3]</source>
        <translation>remove: 인덱스 [%1 - %2]이(가) 범위 [0 - %3]을(를) 벗어남</translation>
    </message>
    <message>
        <source>remove: incorrect number of arguments</source>
        <translation>remove: 인자 개수가 잘못됨</translation>
    </message>
    <message>
        <source>insert: index %1 out of range</source>
        <translation>insert: 인덱스 %1이(가) 범위를 벗어남</translation>
    </message>
    <message>
        <source>insert: value is not an object</source>
        <translation>insert: 값이 객체가 아님</translation>
    </message>
    <message>
        <source>move: out of range</source>
        <translation>move: 범위를 벗어남</translation>
    </message>
    <message>
        <source>append: value is not an object</source>
        <translation>append: 값이 객체가 아님</translation>
    </message>
    <message>
        <source>set: value is not an object</source>
        <translation>set: 값이 객체가 아님</translation>
    </message>
    <message>
        <source>set: index %1 out of range</source>
        <translation>set: 인덱스 %1이(가) 범위를 벗어남</translation>
    </message>
    <message>
        <source>ListElement: cannot contain nested elements</source>
        <translation>ListElement: 중첩된 원소를 포함할 수 없음</translation>
    </message>
    <message>
        <source>ListElement: cannot use reserved &quot;id&quot; property</source>
        <translation>ListElement: 예약된 &quot;id&quot; 속성을 사용할 수 없음</translation>
    </message>
    <message>
        <source>ListElement: cannot use script for property value</source>
        <translation>ListElement: 속성 값으로 스크립트를 사용할 수 없음</translation>
    </message>
    <message>
        <source>ListModel: undefined property &apos;%1&apos;</source>
        <translation>ListModel: 정의되지 않은 속성 &apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>QQmlObjectCreator</name>
    <message>
        <source>Cannot assign value %1 to property %2</source>
        <translation>속성 %2에 값 %1을(를) 할당할 수 없음</translation>
    </message>
    <message>
        <source>Cannot set properties on %1 as it is null</source>
        <translation>%1이(가) null이므로 속성을 설정할 수 없음</translation>
    </message>
    <message>
        <source>Cannot assign an object to signal property %1</source>
        <translation>객체를 시그널 속성 %1에 할당할 수 없음</translation>
    </message>
    <message>
        <source>Cannot assign object type %1 with no default method</source>
        <translation>객체 형식 %1에 기본 메서드를 지정하지 않고 할당할 수 없음</translation>
    </message>
    <message>
        <source>Cannot connect mismatched signal/slot %1 %vs. %2</source>
        <translation>일치하지 않는 시그널/슬롯 %1 %vs %2을(를) 연결할 수 없음</translation>
    </message>
    <message>
        <source>Cannot assign object to interface property</source>
        <translation>객체를 인터페이스 속성에 할당할 수 없음</translation>
    </message>
    <message>
        <source>Cannot assign object to read only list</source>
        <translation>읽기 전용 목록에 객체를 지정할 수 없음</translation>
    </message>
    <message>
        <source>Cannot assign primitives to lists</source>
        <translation>원시 형식을 목록에 할당할 수 없음</translation>
    </message>
    <message>
        <source>Unable to create object of type %1</source>
        <translation>형식 %1인 객체를 만들 수 없음</translation>
    </message>
    <message>
        <source>Composite Singleton Type %1 is not creatable</source>
        <translation>복합 싱글톤 형식 %1을(를) 만들 수 없음</translation>
    </message>
</context>
<context>
    <name>QQmlObjectModel</name>
    <message>
        <source>insert: index %1 out of range</source>
        <translation>insert: 인덱스 %1이(가) 범위를 벗어남</translation>
    </message>
    <message>
        <source>move: out of range</source>
        <translation>move: 범위를 벗어남</translation>
    </message>
    <message>
        <source>remove: indices [%1 - %2] out of range [0 - %3]</source>
        <translation>remove: 인덱스 [%1 - %2]이(가) 범위 [0 - %3]을(를) 벗어남</translation>
    </message>
</context>
<context>
    <name>QQmlParser</name>
    <message>
        <source>Imported file must be a script</source>
        <translation>가져온 파일이 스크립트여야 함</translation>
    </message>
    <message>
        <source>Module import requires a minor version (missing dot)</source>
        <translation>모듈을 가져오려면 부 버전이 필요함(점이 없음)</translation>
    </message>
    <message>
        <source>Module import requires a minor version (missing number)</source>
        <translation>모듈을 가져오려면 부 버전이 필요함(숫자가 없음)</translation>
    </message>
    <message>
        <source>File import requires a qualifier</source>
        <translation>파일을 가져오려면 지정자가 필요함</translation>
    </message>
    <message>
        <source>Invalid import qualifier</source>
        <translation>잘못된 가져오기 지정자</translation>
    </message>
    <message>
        <source>Invalid module URI</source>
        <translation>잘못된 모듈 URI</translation>
    </message>
    <message>
        <source>Module import requires a version</source>
        <translation>모듈을 가져오려면 버전이 필요함</translation>
    </message>
    <message>
        <source>Module import requires a qualifier</source>
        <translation>모듈을 가져오려면 지정자가 필요함</translation>
    </message>
    <message>
        <source>Unexpected object definition</source>
        <translation>예상하지 못한 객체 선언</translation>
    </message>
    <message>
        <source>Invalid import qualifier ID</source>
        <translation>잘못된 가져오기 식별자 ID</translation>
    </message>
    <message>
        <source>Reserved name &quot;Qt&quot; cannot be used as an qualifier</source>
        <translation>예약된 이름 &quot;Qt&quot;는 지정자 이름으로 사용할 수 없음</translation>
    </message>
    <message>
        <source>Script import qualifiers must be unique.</source>
        <translation>스크립트 가져오기 지정자는 고유해야 합니다.</translation>
    </message>
    <message>
        <source>Script import requires a qualifier</source>
        <translation>스크립트를 가져오려면 지정자가 필요함</translation>
    </message>
    <message>
        <source>Library import requires a version</source>
        <translation>라이브러리를 가져오려면 버전이 필요함</translation>
    </message>
    <message>
        <source>Pragma requires a valid qualifier</source>
        <translation>Pragma에 올바른 지정자가 필요함</translation>
    </message>
    <message>
        <source>Expected parameter type</source>
        <translation>인자 type이 필요함</translation>
    </message>
    <message>
        <source>Invalid signal parameter type: </source>
        <translation>잘못된 시그널 인자 종류:</translation>
    </message>
    <message>
        <source>Invalid property type modifier</source>
        <translation>잘못된 속성 type 수정자</translation>
    </message>
    <message>
        <source>Unexpected property type modifier</source>
        <translation>예상하지 못한 속성 type 수정자</translation>
    </message>
    <message>
        <source>Expected property type</source>
        <translation>속성 type이 필요함</translation>
    </message>
    <message>
        <source>JavaScript declaration outside Script element</source>
        <translation>Script 원소 밖에서 자바스크립트가 선언됨</translation>
    </message>
    <message>
        <source>Illegal syntax for exponential number</source>
        <translation>잘못된 지수 문법</translation>
    </message>
    <message>
        <source>Stray newline in string literal</source>
        <translation>문자열 리터럴에 불필요한 빈 줄이 있음</translation>
    </message>
    <message>
        <source>Illegal unicode escape sequence</source>
        <translation>잘못된 유니코드 탈출 시퀀스</translation>
    </message>
    <message>
        <source>Unexpected token &apos;.&apos;</source>
        <translation>예상하지 못한 토큰 &apos;.&apos;</translation>
    </message>
    <message>
        <source>End of file reached at escape sequence</source>
        <translation>탈출 시퀀스에서 파일의 끝에 도달함</translation>
    </message>
    <message>
        <source>Illegal hexadecimal escape sequence</source>
        <translation>잘못된 16진 탈출 시퀀스</translation>
    </message>
    <message>
        <source>Octal escape sequences are not allowed</source>
        <translation>8진 탈출 시퀀스를 사용할 수 없음</translation>
    </message>
    <message>
        <source>Unclosed string at end of line</source>
        <translation>줄 끝에서 닫히지 않은 문자열</translation>
    </message>
    <message>
        <source>At least one octal digit is required after &apos;0%1&apos;</source>
        <translation>&apos;0%1&apos; 다음에 최소 1개의 8진 숫자가 필요함</translation>
    </message>
    <message>
        <source>At least one binary digit is required after &apos;0%1&apos;</source>
        <translation>&apos;0%1&apos; 다음에 최소 1개의 2진 숫자가 필요함</translation>
    </message>
    <message>
        <source>Decimal numbers can&apos;t start with &apos;0&apos;</source>
        <translation>10진 숫자가 &apos;0&apos;으로 시작할 수 없음</translation>
    </message>
    <message>
        <source>At least one hexadecimal digit is required after &apos;0%1&apos;</source>
        <translation>&apos;0%1&apos; 다음에 최소 1개의 16진 숫자가 필요함</translation>
    </message>
    <message>
        <source>Invalid regular expression flag &apos;%0&apos;</source>
        <translation>잘못된 정규 표현식 플래그 &apos;%0&apos;</translation>
    </message>
    <message>
        <source>Unterminated regular expression backslash sequence</source>
        <translation>종료되지 않은 정규 표현식 백슬래시 시퀀스</translation>
    </message>
    <message>
        <source>Unterminated regular expression class</source>
        <translation>종료되지 않은 정규 표현식 클래스</translation>
    </message>
    <message>
        <source>Unterminated regular expression literal</source>
        <translation>끝나지 않은 정규 표현식 리터럴</translation>
    </message>
    <message>
        <source>Syntax error</source>
        <translation>구문 오류</translation>
    </message>
</context>
<context>
    <name>QQmlPartsModel</name>
    <message>
        <source>The group of a DelegateModel cannot be changed within onChanged</source>
        <translation>onChanged 내에서 DelegateModel의 그룹을 변경할 수 없습니다</translation>
    </message>
    <message>
        <source>Delegate component must be Package type.</source>
        <translation>Delegate 컴포넌트는 Package 형식이어야 합니다.</translation>
    </message>
</context>
<context>
    <name>QQmlPropertyCacheCreatorBase</name>
    <message>
        <source>Fully dynamic types cannot declare new properties.</source>
        <translation>완전 동적 형식에서는 새로운 속성을 선언할 수 없습니다.</translation>
    </message>
    <message>
        <source>Fully dynamic types cannot declare new signals.</source>
        <translation>완전 동적 형식에서는 새로운 시그널을 선언할 수 없습니다.</translation>
    </message>
    <message>
        <source>Fully Dynamic types cannot declare new functions.</source>
        <translation>완전 동적 형식에서는 새로운 함수를 선언할 수 없습니다.</translation>
    </message>
    <message>
        <source>Non-existent attached object</source>
        <translation>존재하지 않는 첨부된 객체</translation>
    </message>
    <message>
        <source>Cannot override FINAL property</source>
        <translation>FINAL 속성을 재정의할 수 없음</translation>
    </message>
    <message>
        <source>Invalid signal parameter type: %1</source>
        <translation>잘못된 시그널 인자 종류: %1</translation>
    </message>
    <message>
        <source>Duplicate signal name: invalid override of property change signal or superclass signal</source>
        <translation>중복된 시그널 이름: 속성 변경 시그널이나 상위 클래스의 시그널을 잘못 재정의함</translation>
    </message>
    <message>
        <source>Duplicate method name: invalid override of property change signal or superclass signal</source>
        <translation>중복된 메서드 이름: 속성 변경 시그널이나 상위 클래스의 시그널을 잘못 재정의함</translation>
    </message>
    <message>
        <source>Invalid property type</source>
        <translation>잘못된 속성 형식</translation>
    </message>
    <message>
        <source>Cyclic alias</source>
        <translation>별명의 순환 참조</translation>
    </message>
    <message>
        <source>Invalid alias target</source>
        <translation>잘못된 별명 대상</translation>
    </message>
</context>
<context>
    <name>QQmlPropertyValidator</name>
    <message>
        <source>Property assignment expected</source>
        <translation>속성 할당이 필요함</translation>
    </message>
    <message>
        <source>Invalid use of namespace</source>
        <translation>잘못된 네임스페이스 사용</translation>
    </message>
    <message>
        <source>Invalid attached object assignment</source>
        <translation>잘못된 첨부된 객체 할당</translation>
    </message>
    <message>
        <source>&quot;%1.%2&quot; is not available in %3 %4.%5.</source>
        <translation>&quot;%1.%2&quot;은(는) %3 %4.%5에서 사용할 수 없습니다.</translation>
    </message>
    <message>
        <source>&quot;%1.%2&quot; is not available due to component versioning.</source>
        <translation>&quot;%1.%2&quot;은(는) 구성 요소 버전 때문에 사용할 수 없습니다.</translation>
    </message>
    <message>
        <source>Cannot assign a value directly to a grouped property</source>
        <translation>그룹 속성에 값을 직접 할당할 수 없음</translation>
    </message>
    <message>
        <source>Attached properties cannot be used here</source>
        <translation>여기에 첨부된 속성을 사용할 수 없음</translation>
    </message>
    <message>
        <source>Invalid property assignment: &quot;%1&quot; is a read-only property</source>
        <translation>잘못된 속성 대입: &quot;%1&quot;은(는) 읽기 전용 속성</translation>
    </message>
    <message>
        <source>Cannot assign multiple values to a script property</source>
        <translation>스크립트 속성에 여러 값을 할당할 수 없음</translation>
    </message>
    <message>
        <source>Cannot assign multiple values to a singular property</source>
        <translation>단일 속성에 여러 값을 할당할 수 없음</translation>
    </message>
    <message>
        <source>Property has already been assigned a value</source>
        <translation>속성에 이미 값이 할당됨</translation>
    </message>
    <message>
        <source>Invalid grouped property access</source>
        <translation>잘못된 그룹 속성 접근</translation>
    </message>
    <message>
        <source>Invalid grouped property access: Property &quot;%1&quot; with primitive type &quot;%2&quot;.</source>
        <translation>잘못된 그룹 속성 접근: 속성 &quot;%1&quot;의 원시 형식 &quot;%2&quot;.</translation>
    </message>
    <message>
        <source>Invalid grouped property access: Property &quot;%1&quot; with type &quot;%2&quot;, which is not a value type</source>
        <translation>잘못된 그룹 속성 접근: 속성 &quot;%1&quot;(형식 &quot;%2&quot;)은(는) 값 형식이 아님</translation>
    </message>
    <message>
        <source>Cannot assign to non-existent default property</source>
        <translation>존재하지 않는 기본 속성에 할당할 수 없음</translation>
    </message>
    <message>
        <source>Cannot assign to non-existent property &quot;%1&quot;</source>
        <translation>존재하지 않는 속성 &quot;%1&quot;에 할당할 수 없음</translation>
    </message>
    <message>
        <source>Invalid use of id property with a value type</source>
        <translation>id 속성의 값 형식을 잘못 사용함</translation>
    </message>
    <message>
        <source>Cannot assign primitives to lists</source>
        <translation>원시 형식을 목록에 할당할 수 없음</translation>
    </message>
    <message>
        <source>Invalid property assignment: unknown enumeration</source>
        <translation>잘못된 속성 대입: 알 수 없는 열거형</translation>
    </message>
    <message>
        <source> - Assigning null to incompatible properties in QML is deprecated. This will become a compile error in future versions of Qt.</source>
        <translation> - QML에서 호환되지 않는 속성에 null을 할당하는 것은 오래되었습니다. Qt의 이후 버전에서는 컴파일 오류가 발생할 것입니다.</translation>
    </message>
    <message>
        <source>Invalid property assignment: string expected</source>
        <translation>잘못된 속성 대입: 문자열이 필요함</translation>
    </message>
    <message>
        <source>Invalid property assignment: string or string list expected</source>
        <translation>잘못된 속성 대입: 문자열이나 문자열 목록이 필요함</translation>
    </message>
    <message>
        <source>Invalid property assignment: byte array expected</source>
        <translation>잘못된 속성 대입: 바이트 배열이 필요함</translation>
    </message>
    <message>
        <source>Invalid property assignment: url expected</source>
        <translation>잘못된 속성 대입: url이 필요함</translation>
    </message>
    <message>
        <source>Invalid property assignment: unsigned int expected</source>
        <translation>잘못된 속성 대입: 부호 없는 int가 필요함</translation>
    </message>
    <message>
        <source>Invalid property assignment: int expected</source>
        <translation>잘못된 속성 대입: int가 필요함</translation>
    </message>
    <message>
        <source>Invalid property assignment: number expected</source>
        <translation>잘못된 속성 대입: 숫자가 필요함</translation>
    </message>
    <message>
        <source>Invalid property assignment: color expected</source>
        <translation>잘못된 속성 대입: 색상이 필요함</translation>
    </message>
    <message>
        <source>Invalid property assignment: date expected</source>
        <translation>잘못된 속성 대입: 날짜가 필요함</translation>
    </message>
    <message>
        <source>Invalid property assignment: time expected</source>
        <translation>잘못된 속성 대입: 시간이 필요함</translation>
    </message>
    <message>
        <source>Invalid property assignment: datetime expected</source>
        <translation>잘못된 속성 대입: 날짜와 시간이 필요함</translation>
    </message>
    <message>
        <source>Invalid property assignment: point expected</source>
        <translation>잘못된 속성 대입: 점이 필요함</translation>
    </message>
    <message>
        <source>Invalid property assignment: size expected</source>
        <translation>잘못된 속성 대입: 크기가 필요함</translation>
    </message>
    <message>
        <source>Invalid property assignment: rect expected</source>
        <translation>잘못된 속성 대입: 사각형이 필요함</translation>
    </message>
    <message>
        <source>Invalid property assignment: boolean expected</source>
        <translation>잘못된 속성 대입: 참/거짓이 필요함</translation>
    </message>
    <message>
        <source>Invalid property assignment: 2D vector expected</source>
        <translation>잘못된 속성 대입: 2차원 벡터가 필요함</translation>
    </message>
    <message>
        <source>Invalid property assignment: 3D vector expected</source>
        <translation>잘못된 속성 대입: 3차원 벡터가 필요함</translation>
    </message>
    <message>
        <source>Invalid property assignment: 4D vector expected</source>
        <translation>잘못된 속성 대입: 4차원 벡터가 필요함</translation>
    </message>
    <message>
        <source>Invalid property assignment: quaternion expected</source>
        <translation>잘못된 속성 대입: 사원수가 필요함</translation>
    </message>
    <message>
        <source>Invalid property assignment: regular expression expected; use /pattern/ syntax</source>
        <translation>잘못된 속성 대입: 정규 표현식이 필요함, /pattern/ 문법 사용</translation>
    </message>
    <message>
        <source>Invalid property assignment: number or array of numbers expected</source>
        <translation>잘못된 속성 대입: 숫자 또는 숫자 배열이 필요함</translation>
    </message>
    <message>
        <source>Invalid property assignment: int or array of ints expected</source>
        <translation>잘못된 속성 대입: int 또는 int 배열이 필요함</translation>
    </message>
    <message>
        <source>Invalid property assignment: bool or array of bools expected</source>
        <translation>잘못된 속성 대입: bool 또는 bool 배열이 필요함</translation>
    </message>
    <message>
        <source>Invalid property assignment: url or array of urls expected</source>
        <translation>잘못된 속성 대입: url 또는 url 배열이 필요함</translation>
    </message>
    <message>
        <source>Invalid property assignment: string or array of strings expected</source>
        <translation>잘못된 속성 대입: string 또는 string 배열이 필요함</translation>
    </message>
    <message>
        <source>Invalid property assignment: unsupported type &quot;%1&quot;</source>
        <translation>잘못된 속성 대입: 지원하지 않는 형식 &quot;%1&quot;</translation>
    </message>
    <message>
        <source>&quot;%1&quot; cannot operate on &quot;%2&quot;</source>
        <translation>&quot;%1&quot;은(는) &quot;%2&quot;에서 작동할 수 없음</translation>
    </message>
    <message>
        <source>Cannot assign object to list property &quot;%1&quot;</source>
        <translation>객체를 목록 속성 &quot;%1&quot;에 할당할 수 없음</translation>
    </message>
    <message>
        <source>Cannot assign value of type &quot;%1&quot; to property &quot;%2&quot;, expecting &quot;%3&quot;</source>
        <translation>형식이 &quot;%1&quot;인 값을 &quot;%2&quot; 속성에 할당할 수 없음, &quot;%3&quot;을(를) 예상함</translation>
    </message>
    <message>
        <source>Cannot assign value of type &quot;%1&quot; to property &quot;%2&quot;, expecting an object</source>
        <translation>형식이 &quot;%1&quot;인 값을 &quot;%2&quot; 속성에 할당할 수 없음, 객체를 예상함</translation>
    </message>
    <message>
        <source>Cannot assign object of type &quot;%1&quot; to property of type &quot;%2&quot; as the former is neither the same as the latter nor a sub-class of it.</source>
        <translation>형식이 동일하지 않거나 하위 클래스가 아니기 때문에 형식이 &quot;%1&quot;인 객체를 형식이 &quot;%2&quot;인 속성에 할당할 수 없습니다.</translation>
    </message>
    <message>
        <source>Cannot assign to property of unknown type &quot;%1&quot;.</source>
        <translation>알 수 없는 형식 &quot;%1&quot;인 속성에 할당할 수 없습니다.</translation>
    </message>
    <message>
        <source>Invalid property assignment: script expected</source>
        <translation>잘못된 속성 대입: script가 필요함</translation>
    </message>
</context>
<context>
    <name>QQmlRewrite</name>
    <message>
        <source>Signal uses unnamed parameter followed by named parameter.</source>
        <translation>시그널의 이름 없는 인자 다음에 이름 있는 인자가 있습니다.</translation>
    </message>
    <message>
        <source>Signal parameter &quot;%1&quot; hides global variable.</source>
        <translation>시그널 인자 &quot;%1&quot;이(가) 전역 변수를 숨깁니다.</translation>
    </message>
</context>
<context>
    <name>QQmlTypeData</name>
    <message>
        <source>Composite Singleton Type %1 is not creatable.</source>
        <translation>복합 싱글톤 형식 %1을(를) 만들 수 없습니다.</translation>
    </message>
    <message>
        <source>Element is not creatable.</source>
        <translation>원소를 만들 수 없습니다.</translation>
    </message>
</context>
<context>
    <name>QQmlTypeLoader</name>
    <message>
        <source>Cannot update qmldir content for &apos;%1&apos;</source>
        <translation>&apos;%1&apos;의 qmldir 내용을 업데이트할 수 없음</translation>
    </message>
    <message>
        <source>No matching type found, pragma Singleton files cannot be used by QQmlComponent.</source>
        <translation>일치하는 형식을 찾을 수 없음, QQmlComponent에서는 pragma Singleton 파일을 사용할 수 없습니다.</translation>
    </message>
    <message>
        <source>pragma Singleton used with a non composite singleton type %1</source>
        <translation>비 복합 싱글톤 형식 %1에서 pragma Singleton이 사용됨</translation>
    </message>
    <message>
        <source>File was compiled ahead of time with an incompatible version of Qt and the original file cannot be found. Please recompile</source>
        <translation>이전에 파일이 호환되지 않는 Qt로 컴파일되었고 원본 파일을 찾을 수 없습니다. 다시 컴파일하십시오</translation>
    </message>
    <message>
        <source>No such file or directory</source>
        <translation>그러한 파일이나 디렉터리가 없음</translation>
    </message>
    <message>
        <source>Script %1 unavailable</source>
        <translation>스크립트 %1을(를) 사용할 수 없음</translation>
    </message>
    <message>
        <source>Type %1 has no inline component type called %2</source>
        <translation>형식 %1에 인라인 구성 요소 형식 %2이(가) 없음</translation>
    </message>
    <message>
        <source>Type %1 unavailable</source>
        <translation>형식 %1을(를) 사용할 수 없음</translation>
    </message>
    <message>
        <source>qmldir defines type as singleton, but no pragma Singleton found in type %1.</source>
        <translation>qmldir 내에서 싱글톤으로 선언하지만 형식 %1에서 pragma Singleton을 찾을 수 없습니다.</translation>
    </message>
    <message>
        <source>File is empty</source>
        <translation>파일이 비어 있음</translation>
    </message>
    <message>
        <source>module &quot;%1&quot; is not installed</source>
        <translation>모듈 &quot;%1&quot;이(가) 설치되지 않았음</translation>
    </message>
    <message>
        <source>Namespace %1 cannot be used as a type</source>
        <translation>네임스페이스 %1을(를) 형식으로 사용할 수 없음</translation>
    </message>
    <message>
        <source>Unreported error adding script import to import database</source>
        <translation>가져오기 데이터베이스에 스크립트를 추가하는 중 보고되지 않은 오류 발생</translation>
    </message>
    <message>
        <source>%1 %2</source>
        <translation>%1 %2</translation>
    </message>
</context>
<context>
    <name>QQuickAbstractAnimation</name>
    <message>
        <source>Cannot animate non-existent property &quot;%1&quot;</source>
        <translation>존재하지 않는 속성 &quot;%1&quot;에 애니메이션을 설정할 수 없음</translation>
    </message>
    <message>
        <source>Cannot animate read-only property &quot;%1&quot;</source>
        <translation>읽기 전용 속성 &quot;%1&quot;에 애니메이션을 설정할 수 없음</translation>
    </message>
</context>
<context>
    <name>QQuickAnchorAnimation</name>
    <message>
        <source>Cannot set a duration of &lt; 0</source>
        <translation>0보다 작은 지속 시간을 설정할 수 없음</translation>
    </message>
</context>
<context>
    <name>QQuickAnchors</name>
    <message>
        <source>Possible anchor loop detected on fill.</source>
        <translation>fill에서 앵커 반복이 감지되었습니다.</translation>
    </message>
    <message>
        <source>Possible anchor loop detected on centerIn.</source>
        <translation>centerIn에서 앵커 반복이 감지되었습니다.</translation>
    </message>
    <message>
        <source>Cannot anchor to an item that isn&apos;t a parent or sibling.</source>
        <translation>부모나 자식이 아닌 항목에 앵커를 설정할 수 없습니다.</translation>
    </message>
    <message>
        <source>Possible anchor loop detected on vertical anchor.</source>
        <translation>수직 앵커에서 앵커 반복이 감지되었습니다.</translation>
    </message>
    <message>
        <source>Possible anchor loop detected on horizontal anchor.</source>
        <translation>수평 앵커에서 앵커 반복이 감지되었습니다.</translation>
    </message>
    <message>
        <source>Cannot specify left, right, and horizontalCenter anchors at the same time.</source>
        <translation>동시에 left, right, horizontalCenter 앵커를 지정할 수 없습니다.</translation>
    </message>
    <message>
        <source>Cannot anchor to a null item.</source>
        <translation>빈 항목에 앵커를 설정할 수 없습니다.</translation>
    </message>
    <message>
        <source>Cannot anchor a horizontal edge to a vertical edge.</source>
        <translation>수평선을 수직선에 앵커로 설정할 수 없습니다.</translation>
    </message>
    <message>
        <source>Cannot anchor item to self.</source>
        <translation>자기 자신에 앵커를 설정할 수 없습니다.</translation>
    </message>
    <message>
        <source>Cannot specify top, bottom, and verticalCenter anchors at the same time.</source>
        <translation>동시에 top, bottom, verticalCenter 앵커를 지정할 수 없습니다.</translation>
    </message>
    <message>
        <source>Baseline anchor cannot be used in conjunction with top, bottom, or verticalCenter anchors.</source>
        <translation>Baseline 앵커는 top, bottom, verticalCenter 앵커와 동시에 사용할 수 없습니다.</translation>
    </message>
    <message>
        <source>Cannot anchor a vertical edge to a horizontal edge.</source>
        <translation>수직선을 수평선에 앵커로 설정할 수 없습니다.</translation>
    </message>
</context>
<context>
    <name>QQuickBehavior</name>
    <message>
        <source>Cannot change the animation assigned to a Behavior.</source>
        <translation>Behavior에 할당된 애니메이션을 변경할 수 없습니다.</translation>
    </message>
</context>
<context>
    <name>QQuickEnterKeyAttached</name>
    <message>
        <source>EnterKey attached property only works with Items</source>
        <translation>EnterKey 첨부된 속성은 Item에서만 동작함</translation>
    </message>
</context>
<context>
    <name>QQuickFlipable</name>
    <message>
        <source>front is a write-once property</source>
        <translation>front는 한 번만 쓸 수 있는 속성임</translation>
    </message>
    <message>
        <source>back is a write-once property</source>
        <translation>back은 한 번만 쓸 수 있는 속성임</translation>
    </message>
</context>
<context>
    <name>QQuickItemView</name>
    <message>
        <source>Delegate must be of Item type</source>
        <translation>Delegate는 Item 형식이어야 함</translation>
    </message>
</context>
<context>
    <name>QQuickLayoutMirroringAttached</name>
    <message>
        <source>LayoutDirection attached property only works with Items and Windows</source>
        <translation>첨부된 속성 LayoutDirection은 Item이나 Window에서만 동작함</translation>
    </message>
</context>
<context>
    <name>QQuickLoader</name>
    <message>
        <source>setSource: value is not an object</source>
        <translation>setSource: 값이 객체가 아님</translation>
    </message>
</context>
<context>
    <name>QQuickParentAnimation</name>
    <message>
        <source>Unable to preserve appearance under complex transform</source>
        <translation>복합 변형 이후 모양을 보존할 수 없음</translation>
    </message>
    <message>
        <source>Unable to preserve appearance under non-uniform scale</source>
        <translation>불균일 크기 조정 이후 모양을 보존할 수 없음</translation>
    </message>
    <message>
        <source>Unable to preserve appearance under scale of 0</source>
        <translation>0 이하로 크기를 조정했을 때 모양을 보존할 수 없음</translation>
    </message>
</context>
<context>
    <name>QQuickParentChange</name>
    <message>
        <source>Unable to preserve appearance under complex transform</source>
        <translation>복합 변형 이후 모양을 보존할 수 없음</translation>
    </message>
    <message>
        <source>Unable to preserve appearance under non-uniform scale</source>
        <translation>불균일 크기 조정 이후 모양을 보존할 수 없음</translation>
    </message>
    <message>
        <source>Unable to preserve appearance under scale of 0</source>
        <translation>0 이하로 크기를 조정했을 때 모양을 보존할 수 없음</translation>
    </message>
</context>
<context>
    <name>QQuickPathAnimation</name>
    <message>
        <source>Cannot set a duration of &lt; 0</source>
        <translation>0보다 작은 지속 시간을 설정할 수 없음</translation>
    </message>
</context>
<context>
    <name>QQuickPathView</name>
    <message>
        <source>Delegate must be of Item type</source>
        <translation>Delegate는 Item 형식이어야 함</translation>
    </message>
</context>
<context>
    <name>QQuickPauseAnimation</name>
    <message>
        <source>Cannot set a duration of &lt; 0</source>
        <translation>0보다 작은 지속 시간을 설정할 수 없음</translation>
    </message>
</context>
<context>
    <name>QQuickPixmap</name>
    <message>
        <source>Error decoding: %1: %2</source>
        <translation>%1 디코딩 중 오류 발생: %2</translation>
    </message>
    <message>
        <source>Invalid image provider: %1</source>
        <translation>잘못된 그림 공급자: %1</translation>
    </message>
    <message>
        <source>Failed to get image from provider: %1</source>
        <translation>공급자에서 그림을 가져올 수 없음: %1</translation>
    </message>
    <message>
        <source>Failed to get texture from provider: %1</source>
        <translation>공급자에서 텍스처를 가져올 수 없음: %1</translation>
    </message>
    <message>
        <source>Error decoding: %1</source>
        <translation>디코딩 오류: %1</translation>
    </message>
    <message>
        <source>Cannot open: %1</source>
        <translation>다음을 열 수 없음: %1</translation>
    </message>
</context>
<context>
    <name>QQuickPropertyAnimation</name>
    <message>
        <source>Cannot set a duration of &lt; 0</source>
        <translation>0보다 작은 지속 시간을 설정할 수 없음</translation>
    </message>
</context>
<context>
    <name>QQuickPropertyChanges</name>
    <message>
        <source>PropertyChanges does not support creating state-specific objects.</source>
        <translation>PropertyChanges는 상태별 객체를 만들 수 없습니다.</translation>
    </message>
    <message>
        <source>Cannot assign to non-existent property &quot;%1&quot;</source>
        <translation>존재하지 않는 속성 &quot;%1&quot;에 할당할 수 없음</translation>
    </message>
    <message>
        <source>Cannot assign to read-only property &quot;%1&quot;</source>
        <translation>읽기 전용 속성 &quot;%1&quot;에 할당할 수 없음</translation>
    </message>
</context>
<context>
    <name>QQuickRepeater</name>
    <message>
        <source>Delegate must be of Item type</source>
        <translation>Delegate는 Item 형식이어야 함</translation>
    </message>
</context>
<context>
    <name>QQuickTextUtil</name>
    <message>
        <source>%1 does not support loading non-visual cursor delegates.</source>
        <translation>%1에서 표시할 수 없는 커서 선언을 불러올 수 없습니다.</translation>
    </message>
    <message>
        <source>Could not load cursor delegate</source>
        <translation>커서 선언을 불러올 수 없음</translation>
    </message>
</context>
<context>
    <name>QQuickWindow</name>
    <message>
        <source>Failed to create %1 context for format %2.
This is most likely caused by not having the necessary graphics drivers installed.

Install a driver providing OpenGL 2.0 or higher, or, if this is not possible, make sure the ANGLE Open GL ES 2.0 emulation libraries (%3, %4 and d3dcompiler_*.dll) are available in the application executable&apos;s directory or in a location listed in PATH.</source>
        <extracomment>%1 Context type (Open GL, EGL), %2 format, ANGLE %3, %4 library names</extracomment>
        <translation>형식 %2에 대한 %1 콘텍스트를 생성할 수 없습니다.
필요한 그래픽 드라이버가 설치되어 있지 않을 수도 있습니다.

OpenGL 2.0 이상을 지원하는 드라이버를 설치하시거나, 해당 드라이버를 사용할 수 없다면 실행 파일이 있는 디렉터리나 PATH에 있는 디렉터리에 ANGLE OpenGL ES 2.0 에뮬레이션 라이브러리(%3, %4, d3dcompiler_*.dll)를 설치하십시오.</translation>
    </message>
    <message>
        <source>Failed to create %1 context for format %2</source>
        <extracomment>%1 Context type (Open GL, EGL), %2 format specification</extracomment>
        <translation>형식 %2에 대한 %1 콘텍스트를 생성할 수 없음</translation>
    </message>
    <message>
        <source>Failed to initialize graphics backend for %1.</source>
        <translation>%1의 그래픽 백엔드를 초기화할 수 없습니다.</translation>
    </message>
</context>
<context>
    <name>QQuickWindowQmlImpl</name>
    <message>
        <source>Conflicting properties &apos;visible&apos; and &apos;visibility&apos; for Window &apos;%1&apos;</source>
        <translation>창 &apos;%1&apos;의 &apos;visible&apos;과 &apos;visibility&apos; 속성이 충돌함</translation>
    </message>
    <message>
        <source>Conflicting properties &apos;visible&apos; and &apos;visibility&apos;</source>
        <translation>&apos;visible&apos;과 &apos;visibility&apos; 속성이 충돌함</translation>
    </message>
</context>
<context>
    <name>SignalHandlerConverter</name>
    <message>
        <source>Non-existent attached object</source>
        <translation>존재하지 않는 첨부된 객체</translation>
    </message>
    <message>
        <source>Signal uses unnamed parameter followed by named parameter.</source>
        <translation>시그널의 이름 없는 인자 다음에 이름 있는 인자가 있습니다.</translation>
    </message>
    <message>
        <source>Signal parameter &quot;%1&quot; hides global variable.</source>
        <translation>시그널 인자 &quot;%1&quot;이(가) 전역 변수를 숨깁니다.</translation>
    </message>
    <message>
        <source>&quot;%1.%2&quot; is not available in %3 %4.%5.</source>
        <translation>&quot;%1.%2&quot;은(는) %3 %4.%5에서 사용할 수 없습니다.</translation>
    </message>
    <message>
        <source>&quot;%1.%2&quot; is not available due to component versioning.</source>
        <translation>&quot;%1.%2&quot;은(는) 구성 요소 버전 때문에 사용할 수 없습니다.</translation>
    </message>
    <message>
        <source>Cannot assign a value to a signal (expecting a script to be run)</source>
        <translation>값을 시그널에 지정할 수 없음(스크립트가 실행될 것을 예상함)</translation>
    </message>
    <message>
        <source>Incorrectly specified signal assignment</source>
        <translation>잘못 지정된 시그널 할당</translation>
    </message>
</context>
<context>
    <name>SignalTransition</name>
    <message>
        <source>Specified signal does not exist.</source>
        <translation>지정한 시그널이 존재하지 않습니다.</translation>
    </message>
    <message>
        <source>Cannot assign to non-existent property &quot;%1&quot;</source>
        <translation>존재하지 않는 속성 &quot;%1&quot;에 할당할 수 없음</translation>
    </message>
    <message>
        <source>SignalTransition: script expected</source>
        <translation>SignalTransition: 스크립트가 필요함</translation>
    </message>
</context>
<context>
    <name>qmlRegisterType</name>
    <message>
        <source>Invalid QML %1 name &quot;%2&quot;; type names must begin with an uppercase letter</source>
        <translation>잘못된 QML %1 이름 &quot;%2&quot;. 형식 이름은 대문자로 시작해야 함</translation>
    </message>
    <message>
        <source>Invalid QML %1 name &quot;%2&quot;</source>
        <translation>잘못된 QML %1 이름 &quot;%2&quot;</translation>
    </message>
    <message>
        <source>Cannot install %1 &apos;%2&apos; into protected module &apos;%3&apos; version &apos;%4&apos;</source>
        <translation>보호된 모듈 &apos;%3&apos; 버전 &apos;%4&apos;에 %1 &apos;%2&apos;을(를) 설치할 수 없음</translation>
    </message>
</context>
</TS>
